pub struct CipherTypeCount {
pub type: CipherType,
pub count: u32,
}Expand description
Number of imported ciphers of a given type.
Fields
type: CipherTypecount: u32Trait Implementations
Sourceimpl<UT> ConvertError<UT> for CipherTypeCount
impl<UT> ConvertError<UT> for CipherTypeCount
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<'de> Deserialize<'de> for CipherTypeCount
impl<'de> Deserialize<'de> for CipherTypeCount
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for CipherTypeCount
impl<UT> FfiConverter<UT> for CipherTypeCount
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<CipherTypeCount> for JsValuewhere
CipherTypeCount: Serialize,
impl From<CipherTypeCount> for JsValuewhere
CipherTypeCount: Serialize,
Sourcefn from(value: CipherTypeCount) -> Self
fn from(value: CipherTypeCount) -> Self
Converts to this type from the input type.
Sourceimpl IntoWasmAbi for &CipherTypeCountwhere
CipherTypeCount: Serialize,
impl IntoWasmAbi for &CipherTypeCountwhere
CipherTypeCount: Serialize,
Sourceimpl IntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
impl IntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
Sourceimpl<UT> Lift<UT> for CipherTypeCount
impl<UT> Lift<UT> for CipherTypeCount
Sourceimpl<UT> LiftRef<UT> for CipherTypeCount
impl<UT> LiftRef<UT> for CipherTypeCount
type LiftType = CipherTypeCount
Sourceimpl<UT> LiftReturn<UT> for CipherTypeCount
impl<UT> LiftReturn<UT> for CipherTypeCount
Sourcetype ReturnType = <CipherTypeCount as Lift<UT>>::FfiType
type ReturnType = <CipherTypeCount as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for CipherTypeCount
impl<UT> Lower<UT> for CipherTypeCount
Sourceimpl<UT> LowerError<UT> for CipherTypeCount
impl<UT> LowerError<UT> for CipherTypeCount
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for CipherTypeCount
impl<UT> LowerReturn<UT> for CipherTypeCount
Sourcetype ReturnType = <CipherTypeCount as Lower<UT>>::FfiType
type ReturnType = <CipherTypeCount as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionIntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
impl OptionIntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
Sourceimpl Serialize for CipherTypeCount
impl Serialize for CipherTypeCount
Sourceimpl Tsify for CipherTypeCount
impl Tsify for CipherTypeCount
const DECL: &'static str = "/**\n * Number of imported ciphers of a given type.\n */\nexport interface CipherTypeCount {\n type: CipherType;\n count: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for CipherTypeCount
impl<UT> TypeId<UT> for CipherTypeCount
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorIntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
impl VectorIntoWasmAbi for CipherTypeCountwhere
CipherTypeCount: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for CipherTypeCount
impl WasmDescribe for CipherTypeCount