pub struct ImportSummary {
pub ciphers: Vec<CipherTypeCount>,
pub folders: u32,
pub collections: u32,
}Expand description
Counts of what an import submitted to the server, broken down by cipher type so the client can render its per-type result table.
Fields
ciphers: Vec<CipherTypeCount>folders: u32collections: u32Trait Implementations
Sourceimpl<UT> ConvertError<UT> for ImportSummary
impl<UT> ConvertError<UT> for ImportSummary
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl<'de> Deserialize<'de> for ImportSummary
impl<'de> Deserialize<'de> for ImportSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for ImportSummary
impl<UT> FfiConverter<UT> for ImportSummary
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<ImportSummary> for JsValuewhere
ImportSummary: Serialize,
impl From<ImportSummary> for JsValuewhere
ImportSummary: Serialize,
Sourcefn from(value: ImportSummary) -> Self
fn from(value: ImportSummary) -> Self
Converts to this type from the input type.
Sourceimpl IntoWasmAbi for &ImportSummarywhere
ImportSummary: Serialize,
impl IntoWasmAbi for &ImportSummarywhere
ImportSummary: Serialize,
Sourceimpl IntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
impl IntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
Sourceimpl<UT> Lift<UT> for ImportSummary
impl<UT> Lift<UT> for ImportSummary
Sourceimpl<UT> LiftRef<UT> for ImportSummary
impl<UT> LiftRef<UT> for ImportSummary
type LiftType = ImportSummary
Sourceimpl<UT> LiftReturn<UT> for ImportSummary
impl<UT> LiftReturn<UT> for ImportSummary
Sourcetype ReturnType = <ImportSummary as Lift<UT>>::FfiType
type ReturnType = <ImportSummary as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for ImportSummary
impl<UT> Lower<UT> for ImportSummary
Sourceimpl<UT> LowerError<UT> for ImportSummary
impl<UT> LowerError<UT> for ImportSummary
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for ImportSummary
impl<UT> LowerReturn<UT> for ImportSummary
Sourcetype ReturnType = <ImportSummary as Lower<UT>>::FfiType
type ReturnType = <ImportSummary as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionIntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
impl OptionIntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
Sourceimpl Serialize for ImportSummary
impl Serialize for ImportSummary
Sourceimpl Tsify for ImportSummary
impl Tsify for ImportSummary
const DECL: &'static str = "/**\n * Counts of what an import submitted to the server, broken down by cipher type so the client can\n * render its per-type result table.\n */\nexport interface ImportSummary {\n ciphers: CipherTypeCount[];\n folders: number;\n collections: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for ImportSummary
impl<UT> TypeId<UT> for ImportSummary
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorIntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
impl VectorIntoWasmAbi for ImportSummarywhere
ImportSummary: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for ImportSummary
impl WasmDescribe for ImportSummary
Sourceimpl WasmDescribeVector for ImportSummary
impl WasmDescribeVector for ImportSummary